diff --git a/CHANGELOG.md b/CHANGELOG.md
index 609b42d..9b88410 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -1,11 +1,25 @@
# Changelog
This is the release of the TextMesh Pro UPM package. This release is the equivalent of release 1.0.56.xx.0b3 of TextMesh Pro.
-See the following link for the Release Notes for version 1.0.56.xx.0b2 of TextMesh Pro. http://digitalnativestudios.com/forum/index.php?topic=1363.0
+See the following link for the Release Notes for version 1.0.56.xx.0b3 of TextMesh Pro. http://digitalnativestudios.com/forum/index.php?topic=1363.0
+
+## [1.2.1] - 2018-02-14
+### Changes
+- Package is now backwards compatible with Unity 2018.1.
+- Renamed Assembly Definitions (.asmdef) to new UPM package conventions.
+- Added DisplayName for TMP UPM package.
+- Revised Editor and Playmode tests to ignore / skip over the tests if the required resources are not present in the project.
+- Revised implementation of Font Asset Creator progress bar to use Unity's EditorGUI.ProgressBar instead of custom texture.
+- Fixed an issue where using the material tag in conjunction with fallback font assets was not handled correctly.
+- Fixed an issue where changing the fontStyle property in conjunction with using alternative typefaces / font weights would not correctly trigger a regeneration of the text object.
## [1.2.0] - 2018-01-23
### Changes
-- Package version # increased to 1.2.0 which is the first release for Unity 2018.2.
+- Package version # increased to 1.2.0 which is the first release for Unity 2018.2.
+
+## [1.1.0] - 2018-01-23
+### Changes
+- Package version # increased to 1.1.0 which is the first release for Unity 2018.1.
## [1.0.27] - 2018-01-16
### Changes
diff --git a/Editor Resources/TMPro_DarkSkin.guiskin b/Editor Resources/TMPro_DarkSkin.guiskin
index 8b3aac6..65f3403 100644
--- a/Editor Resources/TMPro_DarkSkin.guiskin
+++ b/Editor Resources/TMPro_DarkSkin.guiskin
@@ -3,7 +3,7 @@
--- !u!114 &11400000
MonoBehaviour:
m_ObjectHideFlags: 0
- m_PrefabParentObject: {fileID: 0}
+ m_CorrespondingSourceObject: {fileID: 0}
m_PrefabInternal: {fileID: 0}
m_GameObject: {fileID: 0}
m_Enabled: 1
@@ -1087,7 +1087,7 @@ MonoBehaviour:
m_verticalScrollbarThumb:
m_Name: verticalscrollbarthumb
m_Normal:
- m_Background: {fileID: 2800000, guid: 418172217e3c48b5ac845d5a5319b8be, type: 3}
+ m_Background: {fileID: 2800000, guid: 4008a9a89683e664d8fe661233721fbf, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0.66176474, g: 0.66176474, b: 0.66176474, a: 1}
m_Hover:
@@ -1355,11 +1355,11 @@ MonoBehaviour:
m_CustomStyles:
- m_Name: Texture Area Box
m_Normal:
- m_Background: {fileID: 2800000, guid: a61d5a1f6f0849019e4619aca2caceee, type: 3}
+ m_Background: {fileID: 2800000, guid: d29cb3985930952479ebe9dc61c7b5ef, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0.7835821, g: 0.7835821, b: 0.7835821, a: 1}
m_Hover:
- m_Background: {fileID: 2800000, guid: a61d5a1f6f0849019e4619aca2caceee, type: 3}
+ m_Background: {fileID: 2800000, guid: d29cb3985930952479ebe9dc61c7b5ef, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0, g: 0, b: 0, a: 1}
m_Active:
@@ -1421,11 +1421,11 @@ MonoBehaviour:
m_StretchHeight: 0
- m_Name: Text Area Box (Editor)
m_Normal:
- m_Background: {fileID: 2800000, guid: 59cd8c8054014d40b400d039ce24aed9, type: 3}
+ m_Background: {fileID: 2800000, guid: 99e3f0c2b5e54694dbb1b61db7550631, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0.8, g: 0.8, b: 0.8, a: 1}
m_Hover:
- m_Background: {fileID: 2800000, guid: 59cd8c8054014d40b400d039ce24aed9, type: 3}
+ m_Background: {fileID: 2800000, guid: 99e3f0c2b5e54694dbb1b61db7550631, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0.8, g: 0.8, b: 0.8, a: 1}
m_Active:
@@ -1487,11 +1487,11 @@ MonoBehaviour:
m_StretchHeight: 0
- m_Name: Text Area Box (Window)
m_Normal:
- m_Background: {fileID: 2800000, guid: 59cd8c8054014d40b400d039ce24aed9, type: 3}
+ m_Background: {fileID: 2800000, guid: 99e3f0c2b5e54694dbb1b61db7550631, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0.8, g: 0.8, b: 0.8, a: 1}
m_Hover:
- m_Background: {fileID: 2800000, guid: 59cd8c8054014d40b400d039ce24aed9, type: 3}
+ m_Background: {fileID: 2800000, guid: 99e3f0c2b5e54694dbb1b61db7550631, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0.8, g: 0.8, b: 0.8, a: 1}
m_Active:
@@ -1553,11 +1553,11 @@ MonoBehaviour:
m_StretchHeight: 0
- m_Name: Square Area Box (85 Grey)
m_Normal:
- m_Background: {fileID: 2800000, guid: d00b1e2da870489d9ea3cb77ca6d72ff, type: 3}
+ m_Background: {fileID: 2800000, guid: 49463c5d22bc0bf4fb122d1a88fc4226, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0.8, g: 0.8, b: 0.8, a: 1}
m_Hover:
- m_Background: {fileID: 2800000, guid: d00b1e2da870489d9ea3cb77ca6d72ff, type: 3}
+ m_Background: {fileID: 2800000, guid: 49463c5d22bc0bf4fb122d1a88fc4226, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0.8, g: 0.8, b: 0.8, a: 1}
m_Active:
@@ -1619,11 +1619,11 @@ MonoBehaviour:
m_StretchHeight: 0
- m_Name: Group Label
m_Normal:
- m_Background: {fileID: 2800000, guid: 59cd8c8054014d40b400d039ce24aed9, type: 3}
+ m_Background: {fileID: 2800000, guid: 99e3f0c2b5e54694dbb1b61db7550631, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0.7019608, g: 0.7019608, b: 0.7019608, a: 1}
m_Hover:
- m_Background: {fileID: 2800000, guid: 59cd8c8054014d40b400d039ce24aed9, type: 3}
+ m_Background: {fileID: 2800000, guid: 99e3f0c2b5e54694dbb1b61db7550631, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0.7019608, g: 0.7019608, b: 0.7019608, a: 1}
m_Active:
@@ -1685,11 +1685,11 @@ MonoBehaviour:
m_StretchHeight: 0
- m_Name: Group Label - Left Half
m_Normal:
- m_Background: {fileID: 2800000, guid: 3ca1bc678db247079b6cd3a9a8444c23, type: 3}
+ m_Background: {fileID: 2800000, guid: 1634b8cf6fe522449aae40f121d55c24, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0.7019608, g: 0.7019608, b: 0.7019608, a: 1}
m_Hover:
- m_Background: {fileID: 2800000, guid: 3ca1bc678db247079b6cd3a9a8444c23, type: 3}
+ m_Background: {fileID: 2800000, guid: 1634b8cf6fe522449aae40f121d55c24, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0.7019608, g: 0.7019608, b: 0.7019608, a: 1}
m_Active:
@@ -1751,11 +1751,11 @@ MonoBehaviour:
m_StretchHeight: 0
- m_Name: Section Label
m_Normal:
- m_Background: {fileID: 2800000, guid: 418172217e3c48b5ac845d5a5319b8be, type: 3}
+ m_Background: {fileID: 2800000, guid: 4008a9a89683e664d8fe661233721fbf, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0.078431375, g: 0.078431375, b: 0.078431375, a: 1}
m_Hover:
- m_Background: {fileID: 2800000, guid: 418172217e3c48b5ac845d5a5319b8be, type: 3}
+ m_Background: {fileID: 2800000, guid: 4008a9a89683e664d8fe661233721fbf, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0.078431375, g: 0.078431375, b: 0.078431375, a: 1}
m_Active:
diff --git a/Editor Resources/TMPro_LightSkin.guiskin b/Editor Resources/TMPro_LightSkin.guiskin
index 4ec1bfb..2fe74ae 100644
--- a/Editor Resources/TMPro_LightSkin.guiskin
+++ b/Editor Resources/TMPro_LightSkin.guiskin
@@ -3,7 +3,7 @@
--- !u!114 &11400000
MonoBehaviour:
m_ObjectHideFlags: 0
- m_PrefabParentObject: {fileID: 0}
+ m_CorrespondingSourceObject: {fileID: 0}
m_PrefabInternal: {fileID: 0}
m_GameObject: {fileID: 0}
m_Enabled: 1
@@ -1087,7 +1087,7 @@ MonoBehaviour:
m_verticalScrollbarThumb:
m_Name: verticalscrollbarthumb
m_Normal:
- m_Background: {fileID: 2800000, guid: 59cd8c8054014d40b400d039ce24aed9, type: 3}
+ m_Background: {fileID: 2800000, guid: 99e3f0c2b5e54694dbb1b61db7550631, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 1, g: 1, b: 1, a: 1}
m_Hover:
@@ -1355,11 +1355,11 @@ MonoBehaviour:
m_CustomStyles:
- m_Name: Texture Area Box
m_Normal:
- m_Background: {fileID: 2800000, guid: 418172217e3c48b5ac845d5a5319b8be, type: 3}
+ m_Background: {fileID: 2800000, guid: 4008a9a89683e664d8fe661233721fbf, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0.047058824, g: 0.047058824, b: 0.047058824, a: 1}
m_Hover:
- m_Background: {fileID: 2800000, guid: 418172217e3c48b5ac845d5a5319b8be, type: 3}
+ m_Background: {fileID: 2800000, guid: 4008a9a89683e664d8fe661233721fbf, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0, g: 0, b: 0, a: 1}
m_Active:
@@ -1421,11 +1421,11 @@ MonoBehaviour:
m_StretchHeight: 0
- m_Name: Text Area Box (Editor)
m_Normal:
- m_Background: {fileID: 2800000, guid: 418172217e3c48b5ac845d5a5319b8be, type: 3}
+ m_Background: {fileID: 2800000, guid: 4008a9a89683e664d8fe661233721fbf, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0, g: 0, b: 0, a: 1}
m_Hover:
- m_Background: {fileID: 2800000, guid: 418172217e3c48b5ac845d5a5319b8be, type: 3}
+ m_Background: {fileID: 2800000, guid: 4008a9a89683e664d8fe661233721fbf, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0, g: 0, b: 0, a: 1}
m_Active:
@@ -1487,11 +1487,11 @@ MonoBehaviour:
m_StretchHeight: 0
- m_Name: Text Area Box (Window)
m_Normal:
- m_Background: {fileID: 2800000, guid: c60b2493a3ed405b9060856b8afc5f67, type: 3}
+ m_Background: {fileID: 2800000, guid: af978c9ff2a7a784c8afa7637b7ff41e, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0, g: 0, b: 0, a: 1}
m_Hover:
- m_Background: {fileID: 2800000, guid: c60b2493a3ed405b9060856b8afc5f67, type: 3}
+ m_Background: {fileID: 2800000, guid: af978c9ff2a7a784c8afa7637b7ff41e, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0, g: 0, b: 0, a: 1}
m_Active:
@@ -1553,11 +1553,11 @@ MonoBehaviour:
m_StretchHeight: 0
- m_Name: Square Area Box (85 Grey)
m_Normal:
- m_Background: {fileID: 2800000, guid: 51bfa87e654343ac9ec8a6a6622fd5ee, type: 3}
+ m_Background: {fileID: 2800000, guid: e8262811c87d0854093bacaf2a074d62, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0, g: 0, b: 0, a: 1}
m_Hover:
- m_Background: {fileID: 2800000, guid: 51bfa87e654343ac9ec8a6a6622fd5ee, type: 3}
+ m_Background: {fileID: 2800000, guid: e8262811c87d0854093bacaf2a074d62, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0, g: 0, b: 0, a: 1}
m_Active:
@@ -1619,11 +1619,11 @@ MonoBehaviour:
m_StretchHeight: 0
- m_Name: Group Label
m_Normal:
- m_Background: {fileID: 2800000, guid: 418172217e3c48b5ac845d5a5319b8be, type: 3}
+ m_Background: {fileID: 2800000, guid: 4008a9a89683e664d8fe661233721fbf, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0, g: 0, b: 0, a: 1}
m_Hover:
- m_Background: {fileID: 2800000, guid: 418172217e3c48b5ac845d5a5319b8be, type: 3}
+ m_Background: {fileID: 2800000, guid: 4008a9a89683e664d8fe661233721fbf, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0, g: 0, b: 0, a: 1}
m_Active:
@@ -1685,11 +1685,11 @@ MonoBehaviour:
m_StretchHeight: 0
- m_Name: Group Label - Left Half
m_Normal:
- m_Background: {fileID: 2800000, guid: f136b9e34a4a4c4f862aacfad1cda171, type: 3}
+ m_Background: {fileID: 2800000, guid: c56efb0a640c6a349b089888347923f0, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0, g: 0, b: 0, a: 1}
m_Hover:
- m_Background: {fileID: 2800000, guid: f136b9e34a4a4c4f862aacfad1cda171, type: 3}
+ m_Background: {fileID: 2800000, guid: c56efb0a640c6a349b089888347923f0, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0, g: 0, b: 0, a: 1}
m_Active:
@@ -1751,11 +1751,11 @@ MonoBehaviour:
m_StretchHeight: 0
- m_Name: Section Label
m_Normal:
- m_Background: {fileID: 2800000, guid: c60b2493a3ed405b9060856b8afc5f67, type: 3}
+ m_Background: {fileID: 2800000, guid: af978c9ff2a7a784c8afa7637b7ff41e, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0.078431375, g: 0.078431375, b: 0.078431375, a: 1}
m_Hover:
- m_Background: {fileID: 2800000, guid: c60b2493a3ed405b9060856b8afc5f67, type: 3}
+ m_Background: {fileID: 2800000, guid: af978c9ff2a7a784c8afa7637b7ff41e, type: 3}
m_ScaledBackgrounds: []
m_TextColor: {r: 0.078431375, g: 0.078431375, b: 0.078431375, a: 1}
m_Active:
diff --git a/Editor Resources/Textures/Box Area Medium.psd b/Editor Resources/Textures/Box Area 85 Dark.png
similarity index 54%
rename from Editor Resources/Textures/Box Area Medium.psd
rename to Editor Resources/Textures/Box Area 85 Dark.png
index d898027..deff38b 100644
Binary files a/Editor Resources/Textures/Box Area Medium.psd and b/Editor Resources/Textures/Box Area 85 Dark.png differ
diff --git a/Editor Resources/Textures/Box Area 85 Dark.png.meta b/Editor Resources/Textures/Box Area 85 Dark.png.meta
new file mode 100644
index 0000000..242a59c
--- /dev/null
+++ b/Editor Resources/Textures/Box Area 85 Dark.png.meta
@@ -0,0 +1,106 @@
+fileFormatVersion: 2
+guid: d29cb3985930952479ebe9dc61c7b5ef
+TextureImporter:
+ fileIDToRecycleName: {}
+ externalObjects: {}
+ serializedVersion: 5
+ mipmaps:
+ mipMapMode: 0
+ enableMipMap: 0
+ sRGBTexture: 1
+ linearTexture: 0
+ fadeOut: 0
+ borderMipMap: 0
+ mipMapsPreserveCoverage: 0
+ alphaTestReferenceValue: 0.5
+ mipMapFadeDistanceStart: 1
+ mipMapFadeDistanceEnd: 3
+ bumpmap:
+ convertToNormalMap: 0
+ externalNormalMap: 0
+ heightScale: 0.25
+ normalMapFilter: 0
+ isReadable: 0
+ grayScaleToAlpha: 0
+ generateCubemap: 6
+ cubemapConvolution: 0
+ seamlessCubemap: 0
+ textureFormat: 1
+ maxTextureSize: 2048
+ textureSettings:
+ serializedVersion: 2
+ filterMode: -1
+ aniso: 1
+ mipBias: -1
+ wrapU: 1
+ wrapV: 1
+ wrapW: 1
+ nPOTScale: 0
+ lightmap: 0
+ compressionQuality: 50
+ spriteMode: 1
+ spriteExtrude: 1
+ spriteMeshType: 1
+ alignment: 0
+ spritePivot: {x: 0.5, y: 0.5}
+ spritePixelsToUnits: 100
+ spriteBorder: {x: 0, y: 0, z: 0, w: 0}
+ spriteGenerateFallbackPhysicsShape: 1
+ alphaUsage: 1
+ alphaIsTransparency: 1
+ spriteTessellationDetail: -1
+ textureType: 2
+ textureShape: 1
+ singleChannelComponent: 0
+ maxTextureSizeSet: 0
+ compressionQualitySet: 0
+ textureFormatSet: 0
+ platformSettings:
+ - serializedVersion: 2
+ buildTarget: DefaultTexturePlatform
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ - serializedVersion: 2
+ buildTarget: Standalone
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ - serializedVersion: 2
+ buildTarget: iPhone
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ spriteSheet:
+ serializedVersion: 2
+ sprites: []
+ outline: []
+ physicsShape: []
+ bones: []
+ spriteID: 6dc6e12c53821da4a8373458df381119
+ vertices: []
+ indices:
+ edges: []
+ weights: []
+ spritePackingTag:
+ userData:
+ assetBundleName:
+ assetBundleVariant:
diff --git a/Editor Resources/Textures/Box Area 85 Dark.psd.meta b/Editor Resources/Textures/Box Area 85 Dark.psd.meta
deleted file mode 100644
index acf7106..0000000
--- a/Editor Resources/Textures/Box Area 85 Dark.psd.meta
+++ /dev/null
@@ -1,53 +0,0 @@
-fileFormatVersion: 2
-guid: a61d5a1f6f0849019e4619aca2caceee
-TextureImporter:
- fileIDToRecycleName: {}
- serializedVersion: 2
- mipmaps:
- mipMapMode: 0
- enableMipMap: 0
- linearTexture: 1
- correctGamma: 0
- fadeOut: 0
- borderMipMap: 0
- mipMapFadeDistanceStart: 1
- mipMapFadeDistanceEnd: 3
- bumpmap:
- convertToNormalMap: 0
- externalNormalMap: 0
- heightScale: .25
- normalMapFilter: 0
- isReadable: 0
- grayScaleToAlpha: 0
- generateCubemap: 0
- cubemapConvolution: 0
- cubemapConvolutionSteps: 8
- cubemapConvolutionExponent: 1.5
- seamlessCubemap: 0
- textureFormat: -3
- maxTextureSize: 32
- textureSettings:
- filterMode: 1
- aniso: 1
- mipBias: -1
- wrapMode: 1
- nPOTScale: 0
- lightmap: 0
- rGBM: 0
- compressionQuality: 50
- spriteMode: 0
- spriteExtrude: 1
- spriteMeshType: 1
- alignment: 0
- spritePivot: {x: .5, y: .5}
- spriteBorder: {x: 0, y: 0, z: 0, w: 0}
- spritePixelsToUnits: 100
- alphaIsTransparency: 1
- textureType: 2
- buildTargetSettings: []
- spriteSheet:
- sprites: []
- spritePackingTag:
- userData:
- assetBundleName:
- assetBundleVariant:
diff --git a/Editor Resources/Textures/Square Box Area (85 Grey).psd b/Editor Resources/Textures/Box Area Dark (LEFT).png
similarity index 54%
rename from Editor Resources/Textures/Square Box Area (85 Grey).psd
rename to Editor Resources/Textures/Box Area Dark (LEFT).png
index 32034f0..a51c506 100644
Binary files a/Editor Resources/Textures/Square Box Area (85 Grey).psd and b/Editor Resources/Textures/Box Area Dark (LEFT).png differ
diff --git a/Editor Resources/Textures/Box Area Dark (LEFT).png.meta b/Editor Resources/Textures/Box Area Dark (LEFT).png.meta
new file mode 100644
index 0000000..7b76ab9
--- /dev/null
+++ b/Editor Resources/Textures/Box Area Dark (LEFT).png.meta
@@ -0,0 +1,106 @@
+fileFormatVersion: 2
+guid: 1634b8cf6fe522449aae40f121d55c24
+TextureImporter:
+ fileIDToRecycleName: {}
+ externalObjects: {}
+ serializedVersion: 5
+ mipmaps:
+ mipMapMode: 0
+ enableMipMap: 0
+ sRGBTexture: 1
+ linearTexture: 0
+ fadeOut: 0
+ borderMipMap: 0
+ mipMapsPreserveCoverage: 0
+ alphaTestReferenceValue: 0.5
+ mipMapFadeDistanceStart: 1
+ mipMapFadeDistanceEnd: 3
+ bumpmap:
+ convertToNormalMap: 0
+ externalNormalMap: 0
+ heightScale: 0.25
+ normalMapFilter: 0
+ isReadable: 0
+ grayScaleToAlpha: 0
+ generateCubemap: 6
+ cubemapConvolution: 0
+ seamlessCubemap: 0
+ textureFormat: 1
+ maxTextureSize: 2048
+ textureSettings:
+ serializedVersion: 2
+ filterMode: -1
+ aniso: 1
+ mipBias: -1
+ wrapU: 1
+ wrapV: 1
+ wrapW: 1
+ nPOTScale: 0
+ lightmap: 0
+ compressionQuality: 50
+ spriteMode: 1
+ spriteExtrude: 1
+ spriteMeshType: 1
+ alignment: 0
+ spritePivot: {x: 0.5, y: 0.5}
+ spritePixelsToUnits: 100
+ spriteBorder: {x: 0, y: 0, z: 0, w: 0}
+ spriteGenerateFallbackPhysicsShape: 1
+ alphaUsage: 1
+ alphaIsTransparency: 1
+ spriteTessellationDetail: -1
+ textureType: 2
+ textureShape: 1
+ singleChannelComponent: 0
+ maxTextureSizeSet: 0
+ compressionQualitySet: 0
+ textureFormatSet: 0
+ platformSettings:
+ - serializedVersion: 2
+ buildTarget: DefaultTexturePlatform
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ - serializedVersion: 2
+ buildTarget: Standalone
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ - serializedVersion: 2
+ buildTarget: iPhone
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ spriteSheet:
+ serializedVersion: 2
+ sprites: []
+ outline: []
+ physicsShape: []
+ bones: []
+ spriteID: 1fedd638bed16bf48816e76215e5ee45
+ vertices: []
+ indices:
+ edges: []
+ weights: []
+ spritePackingTag:
+ userData:
+ assetBundleName:
+ assetBundleVariant:
diff --git a/Editor Resources/Textures/Box Area Dark (LEFT).psd b/Editor Resources/Textures/Box Area Dark (LEFT).psd
deleted file mode 100644
index 6eca409..0000000
Binary files a/Editor Resources/Textures/Box Area Dark (LEFT).psd and /dev/null differ
diff --git a/Editor Resources/Textures/Box Area Dark (LEFT).psd.meta b/Editor Resources/Textures/Box Area Dark (LEFT).psd.meta
deleted file mode 100644
index 85957d2..0000000
--- a/Editor Resources/Textures/Box Area Dark (LEFT).psd.meta
+++ /dev/null
@@ -1,53 +0,0 @@
-fileFormatVersion: 2
-guid: 3ca1bc678db247079b6cd3a9a8444c23
-TextureImporter:
- fileIDToRecycleName: {}
- serializedVersion: 2
- mipmaps:
- mipMapMode: 0
- enableMipMap: 0
- linearTexture: 1
- correctGamma: 0
- fadeOut: 0
- borderMipMap: 0
- mipMapFadeDistanceStart: 1
- mipMapFadeDistanceEnd: 3
- bumpmap:
- convertToNormalMap: 0
- externalNormalMap: 0
- heightScale: .25
- normalMapFilter: 0
- isReadable: 0
- grayScaleToAlpha: 0
- generateCubemap: 0
- cubemapConvolution: 0
- cubemapConvolutionSteps: 8
- cubemapConvolutionExponent: 1.5
- seamlessCubemap: 0
- textureFormat: -3
- maxTextureSize: 32
- textureSettings:
- filterMode: 1
- aniso: 1
- mipBias: -1
- wrapMode: 1
- nPOTScale: 0
- lightmap: 0
- rGBM: 0
- compressionQuality: 50
- spriteMode: 0
- spriteExtrude: 1
- spriteMeshType: 1
- alignment: 0
- spritePivot: {x: .5, y: .5}
- spriteBorder: {x: 0, y: 0, z: 0, w: 0}
- spritePixelsToUnits: 100
- alphaIsTransparency: 1
- textureType: 2
- buildTargetSettings: []
- spriteSheet:
- sprites: []
- spritePackingTag:
- userData:
- assetBundleName:
- assetBundleVariant:
diff --git a/Editor Resources/Textures/Box Area Dark.psd b/Editor Resources/Textures/Box Area Dark.png
similarity index 54%
rename from Editor Resources/Textures/Box Area Dark.psd
rename to Editor Resources/Textures/Box Area Dark.png
index 823f521..a40daee 100644
Binary files a/Editor Resources/Textures/Box Area Dark.psd and b/Editor Resources/Textures/Box Area Dark.png differ
diff --git a/Editor Resources/Textures/Box Area Dark.png.meta b/Editor Resources/Textures/Box Area Dark.png.meta
new file mode 100644
index 0000000..c420135
--- /dev/null
+++ b/Editor Resources/Textures/Box Area Dark.png.meta
@@ -0,0 +1,106 @@
+fileFormatVersion: 2
+guid: 99e3f0c2b5e54694dbb1b61db7550631
+TextureImporter:
+ fileIDToRecycleName: {}
+ externalObjects: {}
+ serializedVersion: 5
+ mipmaps:
+ mipMapMode: 0
+ enableMipMap: 0
+ sRGBTexture: 1
+ linearTexture: 0
+ fadeOut: 0
+ borderMipMap: 0
+ mipMapsPreserveCoverage: 0
+ alphaTestReferenceValue: 0.5
+ mipMapFadeDistanceStart: 1
+ mipMapFadeDistanceEnd: 3
+ bumpmap:
+ convertToNormalMap: 0
+ externalNormalMap: 0
+ heightScale: 0.25
+ normalMapFilter: 0
+ isReadable: 0
+ grayScaleToAlpha: 0
+ generateCubemap: 6
+ cubemapConvolution: 0
+ seamlessCubemap: 0
+ textureFormat: 1
+ maxTextureSize: 2048
+ textureSettings:
+ serializedVersion: 2
+ filterMode: -1
+ aniso: 1
+ mipBias: -1
+ wrapU: 1
+ wrapV: 1
+ wrapW: 1
+ nPOTScale: 0
+ lightmap: 0
+ compressionQuality: 50
+ spriteMode: 1
+ spriteExtrude: 1
+ spriteMeshType: 1
+ alignment: 0
+ spritePivot: {x: 0.5, y: 0.5}
+ spritePixelsToUnits: 100
+ spriteBorder: {x: 0, y: 0, z: 0, w: 0}
+ spriteGenerateFallbackPhysicsShape: 1
+ alphaUsage: 1
+ alphaIsTransparency: 1
+ spriteTessellationDetail: -1
+ textureType: 2
+ textureShape: 1
+ singleChannelComponent: 0
+ maxTextureSizeSet: 0
+ compressionQualitySet: 0
+ textureFormatSet: 0
+ platformSettings:
+ - serializedVersion: 2
+ buildTarget: DefaultTexturePlatform
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ - serializedVersion: 2
+ buildTarget: Standalone
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ - serializedVersion: 2
+ buildTarget: iPhone
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ spriteSheet:
+ serializedVersion: 2
+ sprites: []
+ outline: []
+ physicsShape: []
+ bones: []
+ spriteID: c4695dae272e4994ea2efdcc6629a37a
+ vertices: []
+ indices:
+ edges: []
+ weights: []
+ spritePackingTag:
+ userData:
+ assetBundleName:
+ assetBundleVariant:
diff --git a/Editor Resources/Textures/Box Area Dark.psd.meta b/Editor Resources/Textures/Box Area Dark.psd.meta
deleted file mode 100644
index b1e7c97..0000000
--- a/Editor Resources/Textures/Box Area Dark.psd.meta
+++ /dev/null
@@ -1,53 +0,0 @@
-fileFormatVersion: 2
-guid: 59cd8c8054014d40b400d039ce24aed9
-TextureImporter:
- fileIDToRecycleName: {}
- serializedVersion: 2
- mipmaps:
- mipMapMode: 0
- enableMipMap: 0
- linearTexture: 1
- correctGamma: 0
- fadeOut: 0
- borderMipMap: 0
- mipMapFadeDistanceStart: 1
- mipMapFadeDistanceEnd: 3
- bumpmap:
- convertToNormalMap: 0
- externalNormalMap: 0
- heightScale: .25
- normalMapFilter: 0
- isReadable: 0
- grayScaleToAlpha: 0
- generateCubemap: 0
- cubemapConvolution: 0
- cubemapConvolutionSteps: 8
- cubemapConvolutionExponent: 1.5
- seamlessCubemap: 0
- textureFormat: -3
- maxTextureSize: 32
- textureSettings:
- filterMode: 1
- aniso: 1
- mipBias: -1
- wrapMode: 1
- nPOTScale: 0
- lightmap: 0
- rGBM: 0
- compressionQuality: 50
- spriteMode: 0
- spriteExtrude: 1
- spriteMeshType: 1
- alignment: 0
- spritePivot: {x: .5, y: .5}
- spriteBorder: {x: 0, y: 0, z: 0, w: 0}
- spritePixelsToUnits: 100
- alphaIsTransparency: 1
- textureType: 2
- buildTargetSettings: []
- spriteSheet:
- sprites: []
- spritePackingTag:
- userData:
- assetBundleName:
- assetBundleVariant:
diff --git a/Editor Resources/Textures/Box Area Light.psd b/Editor Resources/Textures/Box Area Light (LEFT).png
similarity index 55%
rename from Editor Resources/Textures/Box Area Light.psd
rename to Editor Resources/Textures/Box Area Light (LEFT).png
index 166d6fd..6aa642f 100644
Binary files a/Editor Resources/Textures/Box Area Light.psd and b/Editor Resources/Textures/Box Area Light (LEFT).png differ
diff --git a/Editor Resources/Textures/Box Area Light (LEFT).png.meta b/Editor Resources/Textures/Box Area Light (LEFT).png.meta
new file mode 100644
index 0000000..f88c2d1
--- /dev/null
+++ b/Editor Resources/Textures/Box Area Light (LEFT).png.meta
@@ -0,0 +1,106 @@
+fileFormatVersion: 2
+guid: c56efb0a640c6a349b089888347923f0
+TextureImporter:
+ fileIDToRecycleName: {}
+ externalObjects: {}
+ serializedVersion: 5
+ mipmaps:
+ mipMapMode: 0
+ enableMipMap: 0
+ sRGBTexture: 1
+ linearTexture: 0
+ fadeOut: 0
+ borderMipMap: 0
+ mipMapsPreserveCoverage: 0
+ alphaTestReferenceValue: 0.5
+ mipMapFadeDistanceStart: 1
+ mipMapFadeDistanceEnd: 3
+ bumpmap:
+ convertToNormalMap: 0
+ externalNormalMap: 0
+ heightScale: 0.25
+ normalMapFilter: 0
+ isReadable: 0
+ grayScaleToAlpha: 0
+ generateCubemap: 6
+ cubemapConvolution: 0
+ seamlessCubemap: 0
+ textureFormat: 1
+ maxTextureSize: 2048
+ textureSettings:
+ serializedVersion: 2
+ filterMode: -1
+ aniso: 1
+ mipBias: -1
+ wrapU: 1
+ wrapV: 1
+ wrapW: 1
+ nPOTScale: 0
+ lightmap: 0
+ compressionQuality: 50
+ spriteMode: 1
+ spriteExtrude: 1
+ spriteMeshType: 1
+ alignment: 0
+ spritePivot: {x: 0.5, y: 0.5}
+ spritePixelsToUnits: 100
+ spriteBorder: {x: 0, y: 0, z: 0, w: 0}
+ spriteGenerateFallbackPhysicsShape: 1
+ alphaUsage: 1
+ alphaIsTransparency: 1
+ spriteTessellationDetail: -1
+ textureType: 2
+ textureShape: 1
+ singleChannelComponent: 0
+ maxTextureSizeSet: 0
+ compressionQualitySet: 0
+ textureFormatSet: 0
+ platformSettings:
+ - serializedVersion: 2
+ buildTarget: DefaultTexturePlatform
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ - serializedVersion: 2
+ buildTarget: Standalone
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ - serializedVersion: 2
+ buildTarget: iPhone
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ spriteSheet:
+ serializedVersion: 2
+ sprites: []
+ outline: []
+ physicsShape: []
+ bones: []
+ spriteID: 2b44738da20d1d14fa34e644c28cb657
+ vertices: []
+ indices:
+ edges: []
+ weights: []
+ spritePackingTag:
+ userData:
+ assetBundleName:
+ assetBundleVariant:
diff --git a/Editor Resources/Textures/Box Area Light (LEFT).psd.meta b/Editor Resources/Textures/Box Area Light (LEFT).psd.meta
deleted file mode 100644
index 8f4a204..0000000
--- a/Editor Resources/Textures/Box Area Light (LEFT).psd.meta
+++ /dev/null
@@ -1,53 +0,0 @@
-fileFormatVersion: 2
-guid: f136b9e34a4a4c4f862aacfad1cda171
-TextureImporter:
- fileIDToRecycleName: {}
- serializedVersion: 2
- mipmaps:
- mipMapMode: 0
- enableMipMap: 0
- linearTexture: 1
- correctGamma: 0
- fadeOut: 0
- borderMipMap: 0
- mipMapFadeDistanceStart: 1
- mipMapFadeDistanceEnd: 3
- bumpmap:
- convertToNormalMap: 0
- externalNormalMap: 0
- heightScale: .25
- normalMapFilter: 0
- isReadable: 0
- grayScaleToAlpha: 0
- generateCubemap: 0
- cubemapConvolution: 0
- cubemapConvolutionSteps: 8
- cubemapConvolutionExponent: 1.5
- seamlessCubemap: 0
- textureFormat: -3
- maxTextureSize: 32
- textureSettings:
- filterMode: 1
- aniso: 1
- mipBias: -1
- wrapMode: 1
- nPOTScale: 0
- lightmap: 0
- rGBM: 0
- compressionQuality: 50
- spriteMode: 0
- spriteExtrude: 1
- spriteMeshType: 1
- alignment: 0
- spritePivot: {x: .5, y: .5}
- spriteBorder: {x: 0, y: 0, z: 0, w: 0}
- spritePixelsToUnits: 100
- alphaIsTransparency: 1
- textureType: 2
- buildTargetSettings: []
- spriteSheet:
- sprites: []
- spritePackingTag:
- userData:
- assetBundleName:
- assetBundleVariant:
diff --git a/Editor Resources/Textures/Box Area Light (LEFT).psd b/Editor Resources/Textures/Box Area Light.png
similarity index 55%
rename from Editor Resources/Textures/Box Area Light (LEFT).psd
rename to Editor Resources/Textures/Box Area Light.png
index d51806a..880509f 100644
Binary files a/Editor Resources/Textures/Box Area Light (LEFT).psd and b/Editor Resources/Textures/Box Area Light.png differ
diff --git a/Editor Resources/Textures/Box Area Light.png.meta b/Editor Resources/Textures/Box Area Light.png.meta
new file mode 100644
index 0000000..bc369db
--- /dev/null
+++ b/Editor Resources/Textures/Box Area Light.png.meta
@@ -0,0 +1,106 @@
+fileFormatVersion: 2
+guid: 4008a9a89683e664d8fe661233721fbf
+TextureImporter:
+ fileIDToRecycleName: {}
+ externalObjects: {}
+ serializedVersion: 5
+ mipmaps:
+ mipMapMode: 0
+ enableMipMap: 0
+ sRGBTexture: 1
+ linearTexture: 0
+ fadeOut: 0
+ borderMipMap: 0
+ mipMapsPreserveCoverage: 0
+ alphaTestReferenceValue: 0.5
+ mipMapFadeDistanceStart: 1
+ mipMapFadeDistanceEnd: 3
+ bumpmap:
+ convertToNormalMap: 0
+ externalNormalMap: 0
+ heightScale: 0.25
+ normalMapFilter: 0
+ isReadable: 0
+ grayScaleToAlpha: 0
+ generateCubemap: 6
+ cubemapConvolution: 0
+ seamlessCubemap: 0
+ textureFormat: 1
+ maxTextureSize: 2048
+ textureSettings:
+ serializedVersion: 2
+ filterMode: -1
+ aniso: 1
+ mipBias: -1
+ wrapU: 1
+ wrapV: 1
+ wrapW: 1
+ nPOTScale: 0
+ lightmap: 0
+ compressionQuality: 50
+ spriteMode: 1
+ spriteExtrude: 1
+ spriteMeshType: 1
+ alignment: 0
+ spritePivot: {x: 0.5, y: 0.5}
+ spritePixelsToUnits: 100
+ spriteBorder: {x: 0, y: 0, z: 0, w: 0}
+ spriteGenerateFallbackPhysicsShape: 1
+ alphaUsage: 1
+ alphaIsTransparency: 1
+ spriteTessellationDetail: -1
+ textureType: 2
+ textureShape: 1
+ singleChannelComponent: 0
+ maxTextureSizeSet: 0
+ compressionQualitySet: 0
+ textureFormatSet: 0
+ platformSettings:
+ - serializedVersion: 2
+ buildTarget: DefaultTexturePlatform
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ - serializedVersion: 2
+ buildTarget: Standalone
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ - serializedVersion: 2
+ buildTarget: iPhone
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ spriteSheet:
+ serializedVersion: 2
+ sprites: []
+ outline: []
+ physicsShape: []
+ bones: []
+ spriteID: a52aa0d8ce5584e4e8d6f71ba4030d0e
+ vertices: []
+ indices:
+ edges: []
+ weights: []
+ spritePackingTag:
+ userData:
+ assetBundleName:
+ assetBundleVariant:
diff --git a/Editor Resources/Textures/Box Area Light.psd.meta b/Editor Resources/Textures/Box Area Light.psd.meta
deleted file mode 100644
index 0da53f4..0000000
--- a/Editor Resources/Textures/Box Area Light.psd.meta
+++ /dev/null
@@ -1,53 +0,0 @@
-fileFormatVersion: 2
-guid: 418172217e3c48b5ac845d5a5319b8be
-TextureImporter:
- fileIDToRecycleName: {}
- serializedVersion: 2
- mipmaps:
- mipMapMode: 0
- enableMipMap: 0
- linearTexture: 1
- correctGamma: 0
- fadeOut: 0
- borderMipMap: 0
- mipMapFadeDistanceStart: 1
- mipMapFadeDistanceEnd: 3
- bumpmap:
- convertToNormalMap: 0
- externalNormalMap: 0
- heightScale: .25
- normalMapFilter: 0
- isReadable: 0
- grayScaleToAlpha: 0
- generateCubemap: 0
- cubemapConvolution: 0
- cubemapConvolutionSteps: 8
- cubemapConvolutionExponent: 1.5
- seamlessCubemap: 0
- textureFormat: -3
- maxTextureSize: 32
- textureSettings:
- filterMode: 1
- aniso: 1
- mipBias: -1
- wrapMode: 1
- nPOTScale: 0
- lightmap: 0
- rGBM: 0
- compressionQuality: 50
- spriteMode: 0
- spriteExtrude: 1
- spriteMeshType: 1
- alignment: 0
- spritePivot: {x: .5, y: .5}
- spriteBorder: {x: 0, y: 0, z: 0, w: 0}
- spritePixelsToUnits: 100
- alphaIsTransparency: 1
- textureType: 2
- buildTargetSettings: []
- spriteSheet:
- sprites: []
- spritePackingTag:
- userData:
- assetBundleName:
- assetBundleVariant:
diff --git a/Editor Resources/Textures/Box Area Medium (LEFT).png b/Editor Resources/Textures/Box Area Medium (LEFT).png
new file mode 100644
index 0000000..735b209
Binary files /dev/null and b/Editor Resources/Textures/Box Area Medium (LEFT).png differ
diff --git a/Editor Resources/Textures/Box Area Medium (LEFT).png.meta b/Editor Resources/Textures/Box Area Medium (LEFT).png.meta
new file mode 100644
index 0000000..a43f734
--- /dev/null
+++ b/Editor Resources/Textures/Box Area Medium (LEFT).png.meta
@@ -0,0 +1,106 @@
+fileFormatVersion: 2
+guid: d77259f363c009b41b4eb3a0676705d8
+TextureImporter:
+ fileIDToRecycleName: {}
+ externalObjects: {}
+ serializedVersion: 5
+ mipmaps:
+ mipMapMode: 0
+ enableMipMap: 0
+ sRGBTexture: 1
+ linearTexture: 0
+ fadeOut: 0
+ borderMipMap: 0
+ mipMapsPreserveCoverage: 0
+ alphaTestReferenceValue: 0.5
+ mipMapFadeDistanceStart: 1
+ mipMapFadeDistanceEnd: 3
+ bumpmap:
+ convertToNormalMap: 0
+ externalNormalMap: 0
+ heightScale: 0.25
+ normalMapFilter: 0
+ isReadable: 0
+ grayScaleToAlpha: 0
+ generateCubemap: 6
+ cubemapConvolution: 0
+ seamlessCubemap: 0
+ textureFormat: 1
+ maxTextureSize: 2048
+ textureSettings:
+ serializedVersion: 2
+ filterMode: -1
+ aniso: 1
+ mipBias: -1
+ wrapU: 1
+ wrapV: 1
+ wrapW: 1
+ nPOTScale: 0
+ lightmap: 0
+ compressionQuality: 50
+ spriteMode: 1
+ spriteExtrude: 1
+ spriteMeshType: 1
+ alignment: 0
+ spritePivot: {x: 0.5, y: 0.5}
+ spritePixelsToUnits: 100
+ spriteBorder: {x: 0, y: 0, z: 0, w: 0}
+ spriteGenerateFallbackPhysicsShape: 1
+ alphaUsage: 1
+ alphaIsTransparency: 1
+ spriteTessellationDetail: -1
+ textureType: 2
+ textureShape: 1
+ singleChannelComponent: 0
+ maxTextureSizeSet: 0
+ compressionQualitySet: 0
+ textureFormatSet: 0
+ platformSettings:
+ - serializedVersion: 2
+ buildTarget: DefaultTexturePlatform
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ - serializedVersion: 2
+ buildTarget: Standalone
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ - serializedVersion: 2
+ buildTarget: iPhone
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ spriteSheet:
+ serializedVersion: 2
+ sprites: []
+ outline: []
+ physicsShape: []
+ bones: []
+ spriteID: 051a35b593f347a47b0cd540151f71b3
+ vertices: []
+ indices:
+ edges: []
+ weights: []
+ spritePackingTag:
+ userData:
+ assetBundleName:
+ assetBundleVariant:
diff --git a/Editor Resources/Textures/Box Area Medium (LEFT).psd b/Editor Resources/Textures/Box Area Medium (LEFT).psd
deleted file mode 100644
index ea04bbc..0000000
Binary files a/Editor Resources/Textures/Box Area Medium (LEFT).psd and /dev/null differ
diff --git a/Editor Resources/Textures/Box Area Medium (LEFT).psd.meta b/Editor Resources/Textures/Box Area Medium (LEFT).psd.meta
deleted file mode 100644
index 02d074b..0000000
--- a/Editor Resources/Textures/Box Area Medium (LEFT).psd.meta
+++ /dev/null
@@ -1,53 +0,0 @@
-fileFormatVersion: 2
-guid: 56a60c07670f4bc6a148329bb7a4952c
-TextureImporter:
- fileIDToRecycleName: {}
- serializedVersion: 2
- mipmaps:
- mipMapMode: 0
- enableMipMap: 0
- linearTexture: 1
- correctGamma: 0
- fadeOut: 0
- borderMipMap: 0
- mipMapFadeDistanceStart: 1
- mipMapFadeDistanceEnd: 3
- bumpmap:
- convertToNormalMap: 0
- externalNormalMap: 0
- heightScale: .25
- normalMapFilter: 0
- isReadable: 0
- grayScaleToAlpha: 0
- generateCubemap: 0
- cubemapConvolution: 0
- cubemapConvolutionSteps: 8
- cubemapConvolutionExponent: 1.5
- seamlessCubemap: 0
- textureFormat: -3
- maxTextureSize: 32
- textureSettings:
- filterMode: 1
- aniso: 1
- mipBias: -1
- wrapMode: 1
- nPOTScale: 0
- lightmap: 0
- rGBM: 0
- compressionQuality: 50
- spriteMode: 0
- spriteExtrude: 1
- spriteMeshType: 1
- alignment: 0
- spritePivot: {x: .5, y: .5}
- spriteBorder: {x: 0, y: 0, z: 0, w: 0}
- spritePixelsToUnits: 100
- alphaIsTransparency: 1
- textureType: 2
- buildTargetSettings: []
- spriteSheet:
- sprites: []
- spritePackingTag:
- userData:
- assetBundleName:
- assetBundleVariant:
diff --git a/Editor Resources/Textures/Box Area Medium.png b/Editor Resources/Textures/Box Area Medium.png
new file mode 100644
index 0000000..24a1cae
Binary files /dev/null and b/Editor Resources/Textures/Box Area Medium.png differ
diff --git a/Editor Resources/Textures/Box Area Medium.png.meta b/Editor Resources/Textures/Box Area Medium.png.meta
new file mode 100644
index 0000000..a9b4fb9
--- /dev/null
+++ b/Editor Resources/Textures/Box Area Medium.png.meta
@@ -0,0 +1,106 @@
+fileFormatVersion: 2
+guid: af978c9ff2a7a784c8afa7637b7ff41e
+TextureImporter:
+ fileIDToRecycleName: {}
+ externalObjects: {}
+ serializedVersion: 5
+ mipmaps:
+ mipMapMode: 0
+ enableMipMap: 0
+ sRGBTexture: 1
+ linearTexture: 0
+ fadeOut: 0
+ borderMipMap: 0
+ mipMapsPreserveCoverage: 0
+ alphaTestReferenceValue: 0.5
+ mipMapFadeDistanceStart: 1
+ mipMapFadeDistanceEnd: 3
+ bumpmap:
+ convertToNormalMap: 0
+ externalNormalMap: 0
+ heightScale: 0.25
+ normalMapFilter: 0
+ isReadable: 0
+ grayScaleToAlpha: 0
+ generateCubemap: 6
+ cubemapConvolution: 0
+ seamlessCubemap: 0
+ textureFormat: 1
+ maxTextureSize: 2048
+ textureSettings:
+ serializedVersion: 2
+ filterMode: -1
+ aniso: 1
+ mipBias: -1
+ wrapU: 1
+ wrapV: 1
+ wrapW: 1
+ nPOTScale: 0
+ lightmap: 0
+ compressionQuality: 50
+ spriteMode: 1
+ spriteExtrude: 1
+ spriteMeshType: 1
+ alignment: 0
+ spritePivot: {x: 0.5, y: 0.5}
+ spritePixelsToUnits: 100
+ spriteBorder: {x: 0, y: 0, z: 0, w: 0}
+ spriteGenerateFallbackPhysicsShape: 1
+ alphaUsage: 1
+ alphaIsTransparency: 1
+ spriteTessellationDetail: -1
+ textureType: 2
+ textureShape: 1
+ singleChannelComponent: 0
+ maxTextureSizeSet: 0
+ compressionQualitySet: 0
+ textureFormatSet: 0
+ platformSettings:
+ - serializedVersion: 2
+ buildTarget: DefaultTexturePlatform
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ - serializedVersion: 2
+ buildTarget: Standalone
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ - serializedVersion: 2
+ buildTarget: iPhone
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ spriteSheet:
+ serializedVersion: 2
+ sprites: []
+ outline: []
+ physicsShape: []
+ bones: []
+ spriteID: 0b64ecd1488c0374a97008e95c1c13b2
+ vertices: []
+ indices:
+ edges: []
+ weights: []
+ spritePackingTag:
+ userData:
+ assetBundleName:
+ assetBundleVariant:
diff --git a/Editor Resources/Textures/Box Area Medium.psd.meta b/Editor Resources/Textures/Box Area Medium.psd.meta
deleted file mode 100644
index 6bc72ae..0000000
--- a/Editor Resources/Textures/Box Area Medium.psd.meta
+++ /dev/null
@@ -1,53 +0,0 @@
-fileFormatVersion: 2
-guid: c60b2493a3ed405b9060856b8afc5f67
-TextureImporter:
- fileIDToRecycleName: {}
- serializedVersion: 2
- mipmaps:
- mipMapMode: 0
- enableMipMap: 0
- linearTexture: 1
- correctGamma: 0
- fadeOut: 0
- borderMipMap: 0
- mipMapFadeDistanceStart: 1
- mipMapFadeDistanceEnd: 3
- bumpmap:
- convertToNormalMap: 0
- externalNormalMap: 0
- heightScale: .25
- normalMapFilter: 0
- isReadable: 0
- grayScaleToAlpha: 0
- generateCubemap: 0
- cubemapConvolution: 0
- cubemapConvolutionSteps: 8
- cubemapConvolutionExponent: 1.5
- seamlessCubemap: 0
- textureFormat: -3
- maxTextureSize: 32
- textureSettings:
- filterMode: 1
- aniso: 1
- mipBias: -1
- wrapMode: 1
- nPOTScale: 0
- lightmap: 0
- rGBM: 0
- compressionQuality: 50
- spriteMode: 0
- spriteExtrude: 1
- spriteMeshType: 1
- alignment: 0
- spritePivot: {x: .5, y: .5}
- spriteBorder: {x: 0, y: 0, z: 0, w: 0}
- spritePixelsToUnits: 100
- alphaIsTransparency: 1
- textureType: 2
- buildTargetSettings: []
- spriteSheet:
- sprites: []
- spritePackingTag:
- userData:
- assetBundleName:
- assetBundleVariant:
diff --git a/Editor Resources/Textures/Box Area 85 Dark.psd b/Editor Resources/Textures/Square Box Area (40 Grey).png
similarity index 55%
rename from Editor Resources/Textures/Box Area 85 Dark.psd
rename to Editor Resources/Textures/Square Box Area (40 Grey).png
index c4ceb1e..7b0f4c3 100644
Binary files a/Editor Resources/Textures/Box Area 85 Dark.psd and b/Editor Resources/Textures/Square Box Area (40 Grey).png differ
diff --git a/Editor Resources/Textures/Square Box Area (40 Grey).png.meta b/Editor Resources/Textures/Square Box Area (40 Grey).png.meta
new file mode 100644
index 0000000..c38a461
--- /dev/null
+++ b/Editor Resources/Textures/Square Box Area (40 Grey).png.meta
@@ -0,0 +1,106 @@
+fileFormatVersion: 2
+guid: e8262811c87d0854093bacaf2a074d62
+TextureImporter:
+ fileIDToRecycleName: {}
+ externalObjects: {}
+ serializedVersion: 5
+ mipmaps:
+ mipMapMode: 0
+ enableMipMap: 0
+ sRGBTexture: 1
+ linearTexture: 0
+ fadeOut: 0
+ borderMipMap: 0
+ mipMapsPreserveCoverage: 0
+ alphaTestReferenceValue: 0.5
+ mipMapFadeDistanceStart: 1
+ mipMapFadeDistanceEnd: 3
+ bumpmap:
+ convertToNormalMap: 0
+ externalNormalMap: 0
+ heightScale: 0.25
+ normalMapFilter: 0
+ isReadable: 0
+ grayScaleToAlpha: 0
+ generateCubemap: 6
+ cubemapConvolution: 0
+ seamlessCubemap: 0
+ textureFormat: 1
+ maxTextureSize: 2048
+ textureSettings:
+ serializedVersion: 2
+ filterMode: -1
+ aniso: 1
+ mipBias: -1
+ wrapU: 1
+ wrapV: 1
+ wrapW: 1
+ nPOTScale: 0
+ lightmap: 0
+ compressionQuality: 50
+ spriteMode: 1
+ spriteExtrude: 1
+ spriteMeshType: 1
+ alignment: 0
+ spritePivot: {x: 0.5, y: 0.5}
+ spritePixelsToUnits: 100
+ spriteBorder: {x: 0, y: 0, z: 0, w: 0}
+ spriteGenerateFallbackPhysicsShape: 1
+ alphaUsage: 1
+ alphaIsTransparency: 1
+ spriteTessellationDetail: -1
+ textureType: 2
+ textureShape: 1
+ singleChannelComponent: 0
+ maxTextureSizeSet: 0
+ compressionQualitySet: 0
+ textureFormatSet: 0
+ platformSettings:
+ - serializedVersion: 2
+ buildTarget: DefaultTexturePlatform
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ - serializedVersion: 2
+ buildTarget: Standalone
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ - serializedVersion: 2
+ buildTarget: iPhone
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ spriteSheet:
+ serializedVersion: 2
+ sprites: []
+ outline: []
+ physicsShape: []
+ bones: []
+ spriteID: 4297e134fc8897a448ab043ad49f7912
+ vertices: []
+ indices:
+ edges: []
+ weights: []
+ spritePackingTag:
+ userData:
+ assetBundleName:
+ assetBundleVariant:
diff --git a/Editor Resources/Textures/Square Box Area (40 Grey).psd b/Editor Resources/Textures/Square Box Area (40 Grey).psd
deleted file mode 100644
index 8092f73..0000000
Binary files a/Editor Resources/Textures/Square Box Area (40 Grey).psd and /dev/null differ
diff --git a/Editor Resources/Textures/Square Box Area (40 Grey).psd.meta b/Editor Resources/Textures/Square Box Area (40 Grey).psd.meta
deleted file mode 100644
index 1b9d58d..0000000
--- a/Editor Resources/Textures/Square Box Area (40 Grey).psd.meta
+++ /dev/null
@@ -1,53 +0,0 @@
-fileFormatVersion: 2
-guid: 51bfa87e654343ac9ec8a6a6622fd5ee
-TextureImporter:
- fileIDToRecycleName: {}
- serializedVersion: 2
- mipmaps:
- mipMapMode: 0
- enableMipMap: 0
- linearTexture: 1
- correctGamma: 0
- fadeOut: 0
- borderMipMap: 0
- mipMapFadeDistanceStart: 1
- mipMapFadeDistanceEnd: 3
- bumpmap:
- convertToNormalMap: 0
- externalNormalMap: 0
- heightScale: .25
- normalMapFilter: 0
- isReadable: 0
- grayScaleToAlpha: 0
- generateCubemap: 0
- cubemapConvolution: 0
- cubemapConvolutionSteps: 8
- cubemapConvolutionExponent: 1.5
- seamlessCubemap: 0
- textureFormat: -3
- maxTextureSize: 32
- textureSettings:
- filterMode: -1
- aniso: 1
- mipBias: -1
- wrapMode: 1
- nPOTScale: 0
- lightmap: 0
- rGBM: 0
- compressionQuality: 50
- spriteMode: 0
- spriteExtrude: 1
- spriteMeshType: 1
- alignment: 0
- spritePivot: {x: .5, y: .5}
- spriteBorder: {x: 0, y: 0, z: 0, w: 0}
- spritePixelsToUnits: 100
- alphaIsTransparency: 1
- textureType: 2
- buildTargetSettings: []
- spriteSheet:
- sprites: []
- spritePackingTag:
- userData:
- assetBundleName:
- assetBundleVariant:
diff --git a/Editor Resources/Textures/Square Box Area (85 Grey).png b/Editor Resources/Textures/Square Box Area (85 Grey).png
new file mode 100644
index 0000000..d3e0432
Binary files /dev/null and b/Editor Resources/Textures/Square Box Area (85 Grey).png differ
diff --git a/Editor Resources/Textures/Square Box Area (85 Grey).png.meta b/Editor Resources/Textures/Square Box Area (85 Grey).png.meta
new file mode 100644
index 0000000..bfa6ed4
--- /dev/null
+++ b/Editor Resources/Textures/Square Box Area (85 Grey).png.meta
@@ -0,0 +1,106 @@
+fileFormatVersion: 2
+guid: 49463c5d22bc0bf4fb122d1a88fc4226
+TextureImporter:
+ fileIDToRecycleName: {}
+ externalObjects: {}
+ serializedVersion: 5
+ mipmaps:
+ mipMapMode: 0
+ enableMipMap: 0
+ sRGBTexture: 1
+ linearTexture: 0
+ fadeOut: 0
+ borderMipMap: 0
+ mipMapsPreserveCoverage: 0
+ alphaTestReferenceValue: 0.5
+ mipMapFadeDistanceStart: 1
+ mipMapFadeDistanceEnd: 3
+ bumpmap:
+ convertToNormalMap: 0
+ externalNormalMap: 0
+ heightScale: 0.25
+ normalMapFilter: 0
+ isReadable: 0
+ grayScaleToAlpha: 0
+ generateCubemap: 6
+ cubemapConvolution: 0
+ seamlessCubemap: 0
+ textureFormat: 1
+ maxTextureSize: 2048
+ textureSettings:
+ serializedVersion: 2
+ filterMode: -1
+ aniso: 1
+ mipBias: -1
+ wrapU: 1
+ wrapV: 1
+ wrapW: 1
+ nPOTScale: 0
+ lightmap: 0
+ compressionQuality: 50
+ spriteMode: 1
+ spriteExtrude: 1
+ spriteMeshType: 1
+ alignment: 0
+ spritePivot: {x: 0.5, y: 0.5}
+ spritePixelsToUnits: 100
+ spriteBorder: {x: 0, y: 0, z: 0, w: 0}
+ spriteGenerateFallbackPhysicsShape: 1
+ alphaUsage: 1
+ alphaIsTransparency: 1
+ spriteTessellationDetail: -1
+ textureType: 2
+ textureShape: 1
+ singleChannelComponent: 0
+ maxTextureSizeSet: 0
+ compressionQualitySet: 0
+ textureFormatSet: 0
+ platformSettings:
+ - serializedVersion: 2
+ buildTarget: DefaultTexturePlatform
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ - serializedVersion: 2
+ buildTarget: Standalone
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ - serializedVersion: 2
+ buildTarget: iPhone
+ maxTextureSize: 32
+ resizeAlgorithm: 0
+ textureFormat: -1
+ textureCompression: 0
+ compressionQuality: 50
+ crunchedCompression: 0
+ allowsAlphaSplitting: 0
+ overridden: 0
+ androidETC2FallbackOverride: 0
+ spriteSheet:
+ serializedVersion: 2
+ sprites: []
+ outline: []
+ physicsShape: []
+ bones: []
+ spriteID: 4cb842fc229775246bc8e619991f9218
+ vertices: []
+ indices:
+ edges: []
+ weights: []
+ spritePackingTag:
+ userData:
+ assetBundleName:
+ assetBundleVariant:
diff --git a/Editor Resources/Textures/Square Box Area (85 Grey).psd.meta b/Editor Resources/Textures/Square Box Area (85 Grey).psd.meta
deleted file mode 100644
index 6a07c23..0000000
--- a/Editor Resources/Textures/Square Box Area (85 Grey).psd.meta
+++ /dev/null
@@ -1,53 +0,0 @@
-fileFormatVersion: 2
-guid: d00b1e2da870489d9ea3cb77ca6d72ff
-TextureImporter:
- fileIDToRecycleName: {}
- serializedVersion: 2
- mipmaps:
- mipMapMode: 0
- enableMipMap: 0
- linearTexture: 1
- correctGamma: 0
- fadeOut: 0
- borderMipMap: 0
- mipMapFadeDistanceStart: 1
- mipMapFadeDistanceEnd: 3
- bumpmap:
- convertToNormalMap: 0
- externalNormalMap: 0
- heightScale: .25
- normalMapFilter: 0
- isReadable: 0
- grayScaleToAlpha: 0
- generateCubemap: 0
- cubemapConvolution: 0
- cubemapConvolutionSteps: 8
- cubemapConvolutionExponent: 1.5
- seamlessCubemap: 0
- textureFormat: -3
- maxTextureSize: 32
- textureSettings:
- filterMode: -1
- aniso: 1
- mipBias: -1
- wrapMode: 1
- nPOTScale: 0
- lightmap: 0
- rGBM: 0
- compressionQuality: 50
- spriteMode: 0
- spriteExtrude: 1
- spriteMeshType: 1
- alignment: 0
- spritePivot: {x: .5, y: .5}
- spriteBorder: {x: 0, y: 0, z: 0, w: 0}
- spritePixelsToUnits: 100
- alphaIsTransparency: 1
- textureType: 2
- buildTargetSettings: []
- spriteSheet:
- sprites: []
- spritePackingTag:
- userData:
- assetBundleName:
- assetBundleVariant:
diff --git a/Editor Resources/Textures/progress bar (Light).psd b/Editor Resources/Textures/progress bar (Light).psd
deleted file mode 100644
index ebc87de..0000000
Binary files a/Editor Resources/Textures/progress bar (Light).psd and /dev/null differ
diff --git a/Editor Resources/Textures/progress bar (Light).psd.meta b/Editor Resources/Textures/progress bar (Light).psd.meta
deleted file mode 100644
index 1276537..0000000
--- a/Editor Resources/Textures/progress bar (Light).psd.meta
+++ /dev/null
@@ -1,53 +0,0 @@
-fileFormatVersion: 2
-guid: c47c1bcbba0b4f78ba75f6093698aeb6
-TextureImporter:
- fileIDToRecycleName: {}
- serializedVersion: 2
- mipmaps:
- mipMapMode: 0
- enableMipMap: 0
- linearTexture: 1
- correctGamma: 0
- fadeOut: 0
- borderMipMap: 0
- mipMapFadeDistanceStart: 1
- mipMapFadeDistanceEnd: 3
- bumpmap:
- convertToNormalMap: 0
- externalNormalMap: 0
- heightScale: .25
- normalMapFilter: 0
- isReadable: 0
- grayScaleToAlpha: 0
- generateCubemap: 0
- cubemapConvolution: 0
- cubemapConvolutionSteps: 8
- cubemapConvolutionExponent: 1.5
- seamlessCubemap: 0
- textureFormat: -1
- maxTextureSize: 256
- textureSettings:
- filterMode: -1
- aniso: 1
- mipBias: -1
- wrapMode: 1
- nPOTScale: 0
- lightmap: 0
- rGBM: 0
- compressionQuality: 50
- spriteMode: 0
- spriteExtrude: 1
- spriteMeshType: 1
- alignment: 0
- spritePivot: {x: .5, y: .5}
- spriteBorder: {x: 0, y: 0, z: 0, w: 0}
- spritePixelsToUnits: 100
- alphaIsTransparency: 1
- textureType: 2
- buildTargetSettings: []
- spriteSheet:
- sprites: []
- spritePackingTag:
- userData:
- assetBundleName:
- assetBundleVariant:
diff --git a/Editor Resources/Textures/progress bar.psd b/Editor Resources/Textures/progress bar.psd
deleted file mode 100644
index 244161e..0000000
Binary files a/Editor Resources/Textures/progress bar.psd and /dev/null differ
diff --git a/Editor Resources/Textures/progress bar.psd.meta b/Editor Resources/Textures/progress bar.psd.meta
deleted file mode 100644
index 808cd08..0000000
--- a/Editor Resources/Textures/progress bar.psd.meta
+++ /dev/null
@@ -1,53 +0,0 @@
-fileFormatVersion: 2
-guid: 1e92a74e3a634cc99cc0c1bee43db5be
-TextureImporter:
- fileIDToRecycleName: {}
- serializedVersion: 2
- mipmaps:
- mipMapMode: 0
- enableMipMap: 0
- linearTexture: 1
- correctGamma: 0
- fadeOut: 0
- borderMipMap: 0
- mipMapFadeDistanceStart: 1
- mipMapFadeDistanceEnd: 3
- bumpmap:
- convertToNormalMap: 0
- externalNormalMap: 0
- heightScale: .25
- normalMapFilter: 0
- isReadable: 0
- grayScaleToAlpha: 0
- generateCubemap: 0
- cubemapConvolution: 0
- cubemapConvolutionSteps: 8
- cubemapConvolutionExponent: 1.5
- seamlessCubemap: 0
- textureFormat: -1
- maxTextureSize: 256
- textureSettings:
- filterMode: -1
- aniso: 1
- mipBias: -1
- wrapMode: 1
- nPOTScale: 0
- lightmap: 0
- rGBM: 0
- compressionQuality: 50
- spriteMode: 0
- spriteExtrude: 1
- spriteMeshType: 1
- alignment: 0
- spritePivot: {x: .5, y: .5}
- spriteBorder: {x: 0, y: 0, z: 0, w: 0}
- spritePixelsToUnits: 100
- alphaIsTransparency: 1
- textureType: 2
- buildTargetSettings: []
- spriteSheet:
- sprites: []
- spritePackingTag:
- userData:
- assetBundleName:
- assetBundleVariant:
diff --git a/Scripts/Editor/TMP_SettingsEditor.cs b/Scripts/Editor/TMP_SettingsEditor.cs
index 0a70622..a522d0d 100644
--- a/Scripts/Editor/TMP_SettingsEditor.cs
+++ b/Scripts/Editor/TMP_SettingsEditor.cs
@@ -19,7 +19,6 @@ public class TMP_SettingsEditor : Editor
//private string[] uiStateLabel = new string[] { "(Click to expand)", "(Click to collapse)" };
//private GUIStyle _Label;
-
private SerializedProperty prop_FontAsset;
private SerializedProperty prop_DefaultFontAssetPath;
private SerializedProperty prop_DefaultFontSize;
@@ -107,7 +106,7 @@ public override void OnInspectorGUI()
serializedObject.Update();
- GUILayout.Label("TEXTMESH PRO - SETTINGS", TMP_UIStyleManager.Section_Label);
+ GUILayout.Label("TEXTMESH PRO - SETTINGS (Version - " + TMP_Settings.version + ")", TMP_UIStyleManager.Section_Label);
// TextMeshPro Font Info Panel
EditorGUI.indentLevel = 0;
diff --git a/Scripts/Editor/TMP_UIStyleManager.cs b/Scripts/Editor/TMP_UIStyleManager.cs
index 697622a..1b65aa7 100644
--- a/Scripts/Editor/TMP_UIStyleManager.cs
+++ b/Scripts/Editor/TMP_UIStyleManager.cs
@@ -40,7 +40,7 @@ public static class TMP_UIStyleManager
public static Texture2D alignMidline;
public static Texture2D alignCapline;
- public static Texture2D progressTexture;
+ //public static Texture2D progressTexture;
public static Texture2D selectionBox;
public static GUIContent[] alignContent_A;
@@ -76,7 +76,7 @@ public static void GetUIStyles()
alignMidline = AssetDatabase.LoadAssetAtPath(tmproAssetFolderPath + "/Editor Resources/Textures/btn_AlignMidLine.psd", typeof(Texture2D)) as Texture2D;
alignCapline = AssetDatabase.LoadAssetAtPath(tmproAssetFolderPath + "/Editor Resources/Textures/btn_AlignCapLine.psd", typeof(Texture2D)) as Texture2D;
- progressTexture = AssetDatabase.LoadAssetAtPath(tmproAssetFolderPath + "/Editor Resources/Textures/Progress Bar.psd", typeof(Texture2D)) as Texture2D;
+ //progressTexture = AssetDatabase.LoadAssetAtPath(tmproAssetFolderPath + "/Editor Resources/Textures/Progress Bar.psd", typeof(Texture2D)) as Texture2D;
//selectionBox = AssetDatabase.LoadAssetAtPath(tmproAssetFolderPath + "/Editor Resources/Textures/SelectionBox.psd", typeof(Texture2D)) as Texture2D;
//strikethroughIcon = new GUIContent(AssetDatabase.LoadAssetAtPath(tmproAssetFolderPath + "/Editor Resources/Textures/icon_strikethrough.psd", typeof(Texture2D)) as Texture2D);
selectionBox = EditorGUIUtility.Load("IN thumbnailshadow On@2x") as Texture2D;
@@ -100,7 +100,7 @@ public static void GetUIStyles()
alignMidline = AssetDatabase.LoadAssetAtPath(tmproAssetFolderPath + "/Editor Resources/Textures/btn_AlignMidLine_Light.psd", typeof(Texture2D)) as Texture2D;
alignCapline = AssetDatabase.LoadAssetAtPath(tmproAssetFolderPath + "/Editor Resources/Textures/btn_AlignCapLine_Light.psd", typeof(Texture2D)) as Texture2D;
- progressTexture = AssetDatabase.LoadAssetAtPath(tmproAssetFolderPath + "/Editor Resources/Textures/Progress Bar (Light).psd", typeof(Texture2D)) as Texture2D;
+ //progressTexture = AssetDatabase.LoadAssetAtPath(tmproAssetFolderPath + "/Editor Resources/Textures/Progress Bar (Light).psd", typeof(Texture2D)) as Texture2D;
selectionBox = EditorGUIUtility.Load("IN thumbnailshadow On@2x") as Texture2D;
}
diff --git a/Scripts/Editor/TMPro_FontAssetCreatorWindow.cs b/Scripts/Editor/TMPro_FontAssetCreatorWindow.cs
index 65f610d..c782aeb 100644
--- a/Scripts/Editor/TMPro_FontAssetCreatorWindow.cs
+++ b/Scripts/Editor/TMPro_FontAssetCreatorWindow.cs
@@ -339,6 +339,9 @@ void DrawControls()
EditorGUIUtility.labelWidth = 120f;
EditorGUIUtility.fieldWidth = 160f;
+ // Disable Options if already generating a font atlas texture.
+ GUI.enabled = isProcessing ? false : true;
+
// FONT TTF SELECTION
EditorGUI.BeginChangeCheck();
font_TTF = EditorGUILayout.ObjectField("Font Source", font_TTF, typeof(Font), false, GUILayout.Width(290)) as Font;
@@ -367,7 +370,6 @@ void DrawControls()
EditorGUIUtility.labelWidth = 120f;
EditorGUIUtility.fieldWidth = 160f;
-
// FONT PADDING
font_padding = EditorGUILayout.IntField("Font Padding", font_padding, GUILayout.Width(290));
font_padding = (int)Mathf.Clamp(font_padding, 0f, 64f);
@@ -543,7 +545,7 @@ void DrawControls()
GUILayout.Space(20);
- GUI.enabled = font_TTF == null || isProcessing ? false : true; // Enable Preview if we are not already rendering a font.
+ bool isEnabled = GUI.enabled = font_TTF == null || isProcessing ? false : true; // Enable Preview if we are not already rendering a font.
if (GUILayout.Button("Generate Font Atlas", GUILayout.Width(290)) && characterSequence.Length != 0 && GUI.enabled)
{
if (font_TTF != null)
@@ -655,12 +657,11 @@ void DrawControls()
// FONT RENDERING PROGRESS BAR
GUILayout.Space(1);
- progressRect = GUILayoutUtility.GetRect(288, 20, TMP_UIStyleManager.TextAreaBoxWindow, GUILayout.Width(288), GUILayout.Height(20));
-
- GUI.BeginGroup(progressRect);
- GUI.DrawTextureWithTexCoords(new Rect(2, 0, 288, 20), TMP_UIStyleManager.progressTexture, new Rect(1 - m_renderingProgress, 0, 1, 1));
- GUI.EndGroup();
+ progressRect = GUILayoutUtility.GetRect(0, 20, GUILayout.Width(289));
+ GUI.enabled = true;
+ EditorGUI.ProgressBar(progressRect, Mathf.Max(0.01f, m_renderingProgress), "Generation Progress");
+ GUI.enabled = isEnabled;
// FONT STATUS & INFORMATION
GUISkin skin = GUI.skin;
diff --git a/Scripts/Editor/com.unity.textmeshpro.Editor.asmdef b/Scripts/Editor/Unity.TextMeshPro.Editor.asmdef
similarity index 62%
rename from Scripts/Editor/com.unity.textmeshpro.Editor.asmdef
rename to Scripts/Editor/Unity.TextMeshPro.Editor.asmdef
index d3ddc65..437e221 100644
--- a/Scripts/Editor/com.unity.textmeshpro.Editor.asmdef
+++ b/Scripts/Editor/Unity.TextMeshPro.Editor.asmdef
@@ -1,7 +1,7 @@
{
- "name": "com.unity.textmeshpro.Editor",
+ "name": "Unity.TextMeshPro.Editor",
"references": [
- "com.unity.textmeshpro.Runtime"
+ "Unity.TextMeshPro"
],
"optionalUnityReferences": [],
"includePlatforms": [
diff --git a/Scripts/Editor/com.unity.textmeshpro.Editor.asmdef.meta b/Scripts/Editor/Unity.TextMeshPro.Editor.asmdef.meta
similarity index 100%
rename from Scripts/Editor/com.unity.textmeshpro.Editor.asmdef.meta
rename to Scripts/Editor/Unity.TextMeshPro.Editor.asmdef.meta
diff --git a/Scripts/Runtime/PackageResourceImporterWindow.cs b/Scripts/Runtime/PackageResourceImporterWindow.cs
index 9979127..7bada22 100644
--- a/Scripts/Runtime/PackageResourceImporterWindow.cs
+++ b/Scripts/Runtime/PackageResourceImporterWindow.cs
@@ -216,7 +216,7 @@ string ValidateLocation(string[] paths, string projectPath)
{
for (int i = 0; i < paths.Length; i++)
{
- // Check if any of the matching directories contain a GUISkins directory.
+ // Check if the Editor Resources folder exists.
if (Directory.Exists(paths[i] + "/Editor Resources"))
{
string folderPath = paths[i].Replace(projectPath, "");
diff --git a/Scripts/Runtime/TMP_Settings.cs b/Scripts/Runtime/TMP_Settings.cs
index 4081419..0b582d3 100644
--- a/Scripts/Runtime/TMP_Settings.cs
+++ b/Scripts/Runtime/TMP_Settings.cs
@@ -18,10 +18,9 @@ public class TMP_Settings : ScriptableObject
///
public static string version
{
- get { return instance.m_version; }
+ get { return "1.2.1"; }
}
- [SerializeField]
- private string m_version = "1.0.56.0b3";
+
///
/// Controls if Word Wrapping will be enabled on newly created text objects by default.
diff --git a/Scripts/Runtime/TMP_SubMesh.cs b/Scripts/Runtime/TMP_SubMesh.cs
index 9a547d4..898eeab 100644
--- a/Scripts/Runtime/TMP_SubMesh.cs
+++ b/Scripts/Runtime/TMP_SubMesh.cs
@@ -309,7 +309,11 @@ void ON_MATERIAL_PROPERTY_CHANGED(bool isChanged, Material mat)
void ON_DRAG_AND_DROP_MATERIAL(GameObject obj, Material currentMaterial, Material newMaterial)
{
// Check if event applies to this current object
+ #if UNITY_2018_2_OR_NEWER
if (obj == gameObject || UnityEditor.PrefabUtility.GetCorrespondingObjectFromSource(gameObject) == obj)
+ #else
+ if (obj == gameObject || UnityEditor.PrefabUtility.GetPrefabParent(gameObject) == obj)
+ #endif
{
if (!m_isDefaultMaterial) return;
diff --git a/Scripts/Runtime/TMP_SubMeshUI.cs b/Scripts/Runtime/TMP_SubMeshUI.cs
index db0cfdf..c53453a 100644
--- a/Scripts/Runtime/TMP_SubMeshUI.cs
+++ b/Scripts/Runtime/TMP_SubMeshUI.cs
@@ -400,7 +400,11 @@ void ON_MATERIAL_PROPERTY_CHANGED(bool isChanged, Material mat)
void ON_DRAG_AND_DROP_MATERIAL(GameObject obj, Material currentMaterial, Material newMaterial)
{
// Check if event applies to this current object
+ #if UNITY_2018_2_OR_NEWER
if (obj == gameObject || UnityEditor.PrefabUtility.GetCorrespondingObjectFromSource(gameObject) == obj)
+ #else
+ if (obj == gameObject || UnityEditor.PrefabUtility.GetPrefabParent(gameObject) == obj)
+ #endif
{
if (!m_isDefaultMaterial) return;
diff --git a/Scripts/Runtime/TMP_Text.cs b/Scripts/Runtime/TMP_Text.cs
index 7d01eea..6e57371 100644
--- a/Scripts/Runtime/TMP_Text.cs
+++ b/Scripts/Runtime/TMP_Text.cs
@@ -411,7 +411,7 @@ public float fontScale
public int fontWeight
{
get { return m_fontWeight; }
- set { if (m_fontWeight == value) return; m_fontWeight = value; m_isCalculateSizeRequired = true; SetVerticesDirty(); SetLayoutDirty(); }
+ set { if (m_fontWeight == value) return; m_fontWeight = value; m_havePropertiesChanged = true; m_isCalculateSizeRequired = true; m_isInputParsingRequired = true; SetVerticesDirty(); SetLayoutDirty(); }
}
[SerializeField]
protected int m_fontWeight = 400;
@@ -483,7 +483,7 @@ public float fontSizeMax
public FontStyles fontStyle
{
get { return m_fontStyle; }
- set { if (m_fontStyle == value) return; m_fontStyle = value; m_havePropertiesChanged = true; checkPaddingRequired = true; SetVerticesDirty(); SetLayoutDirty(); }
+ set { if (m_fontStyle == value) return; m_fontStyle = value; m_havePropertiesChanged = true; m_isCalculateSizeRequired = true; m_isInputParsingRequired = true; SetVerticesDirty(); SetLayoutDirty(); }
}
[SerializeField]
protected FontStyles m_fontStyle = FontStyles.Normal;
@@ -6591,7 +6591,7 @@ protected bool ValidateHtmlTag(int[] chars, int startIndex, out int endIndex)
if (materialHashCode == 764638571 || materialHashCode == 523367755)
{
// Check if material font atlas texture matches that of the current font asset.
- if (m_currentFontAsset.atlas.GetInstanceID() != m_currentMaterial.GetTexture(ShaderUtilities.ID_MainTex).GetInstanceID()) return false;
+ //if (m_currentFontAsset.atlas.GetInstanceID() != m_currentMaterial.GetTexture(ShaderUtilities.ID_MainTex).GetInstanceID()) return false;
m_currentMaterial = m_materialReferences[0].material;
m_currentMaterialIndex = 0;
@@ -6606,7 +6606,7 @@ protected bool ValidateHtmlTag(int[] chars, int startIndex, out int endIndex)
if (MaterialReferenceManager.TryGetMaterial(materialHashCode, out tempMaterial))
{
// Check if material font atlas texture matches that of the current font asset.
- if (m_currentFontAsset.atlas.GetInstanceID() != tempMaterial.GetTexture(ShaderUtilities.ID_MainTex).GetInstanceID()) return false;
+ //if (m_currentFontAsset.atlas.GetInstanceID() != tempMaterial.GetTexture(ShaderUtilities.ID_MainTex).GetInstanceID()) return false;
m_currentMaterial = tempMaterial;
@@ -6623,7 +6623,7 @@ protected bool ValidateHtmlTag(int[] chars, int startIndex, out int endIndex)
return false;
// Check if material font atlas texture matches that of the current font asset.
- if (m_currentFontAsset.atlas.GetInstanceID() != tempMaterial.GetTexture(ShaderUtilities.ID_MainTex).GetInstanceID()) return false;
+ //if (m_currentFontAsset.atlas.GetInstanceID() != tempMaterial.GetTexture(ShaderUtilities.ID_MainTex).GetInstanceID()) return false;
// Add new reference to this material in the MaterialReferenceManager
MaterialReferenceManager.AddFontMaterial(materialHashCode, tempMaterial);
diff --git a/Scripts/Runtime/TMPro_EventManager.cs b/Scripts/Runtime/TMPro_EventManager.cs
index bb10e3e..f460f32 100644
--- a/Scripts/Runtime/TMPro_EventManager.cs
+++ b/Scripts/Runtime/TMPro_EventManager.cs
@@ -9,7 +9,6 @@ public enum Compute_DistanceTransform_EventTypes { Processing, Completed };
public static class TMPro_EventManager
{
-
public static readonly FastAction
public override void SetLayoutDirty()
{
- //Debug.Log("SetLayoutDirty() called at frame:" + Time.frameCount + ".");
m_isPreferredWidthDirty = true;
m_isPreferredHeightDirty = true;
diff --git a/Scripts/Runtime/com.unity.textmeshpro.Runtime.asmdef b/Scripts/Runtime/Unity.TextMeshPro.asmdef
similarity index 71%
rename from Scripts/Runtime/com.unity.textmeshpro.Runtime.asmdef
rename to Scripts/Runtime/Unity.TextMeshPro.asmdef
index 6620016..fafc7ed 100644
--- a/Scripts/Runtime/com.unity.textmeshpro.Runtime.asmdef
+++ b/Scripts/Runtime/Unity.TextMeshPro.asmdef
@@ -1,5 +1,5 @@
{
- "name": "com.unity.textmeshpro.Runtime",
+ "name": "Unity.TextMeshPro",
"references": [],
"optionalUnityReferences": [],
"includePlatforms": [],
diff --git a/Tests/Editor/com.unity.textmeshpro.EditorTests.asmdef b/Tests/Editor/Unity.TextMeshPro.Editor.Tests.asmdef
similarity index 57%
rename from Tests/Editor/com.unity.textmeshpro.EditorTests.asmdef
rename to Tests/Editor/Unity.TextMeshPro.Editor.Tests.asmdef
index c09523e..3f09050 100644
--- a/Tests/Editor/com.unity.textmeshpro.EditorTests.asmdef
+++ b/Tests/Editor/Unity.TextMeshPro.Editor.Tests.asmdef
@@ -1,8 +1,8 @@
{
- "name": "com.unity.textmeshpro.EditorTests",
+ "name": "Unity.TextMeshPro.Editor.Tests",
"references": [
- "com.unity.textmeshpro.Runtime",
- "com.unity.textmeshpro.Editor"
+ "Unity.TextMeshPro",
+ "Unity.TextMeshPro.Editor"
],
"optionalUnityReferences": [
"TestAssemblies"
diff --git a/Tests/Editor/com.unity.textmeshpro.EditorTests.asmdef.meta b/Tests/Editor/Unity.TextMeshPro.Editor.Tests.asmdef.meta
similarity index 100%
rename from Tests/Editor/com.unity.textmeshpro.EditorTests.asmdef.meta
rename to Tests/Editor/Unity.TextMeshPro.Editor.Tests.asmdef.meta
diff --git a/Tests/Runtime/TMP_RuntimeTests.cs b/Tests/Runtime/TMP_RuntimeTests.cs
index 1efa52e..89d65f5 100644
--- a/Tests/Runtime/TMP_RuntimeTests.cs
+++ b/Tests/Runtime/TMP_RuntimeTests.cs
@@ -1,6 +1,7 @@
using UnityEngine;
using UnityEngine.TestTools;
using NUnit.Framework;
+using System.IO;
using System.Collections;
using System.Collections.Generic;
@@ -57,6 +58,14 @@ public class TMP_RuntimeTests
[OneTimeSetUp]
public void Setup()
{
+ if (Directory.Exists(Path.GetFullPath("Assets/TextMesh Pro")) == false)
+ {
+ Debug.Log("Skipping over PlayMode tests as TMP Essential Resources are missing from the current test project.");
+ Assert.Ignore();
+
+ return;
+ }
+
GameObject textObject = new GameObject("Text Object");
m_TextComponent = textObject.AddComponent();
@@ -172,5 +181,25 @@ public void Parsing_TextInfo_RichText(int sourceTextIndex, int characterCount, i
Assert.AreEqual(m_TextComponent.textInfo.wordCount, wordCount);
Assert.AreEqual(m_TextComponent.textInfo.lineCount, lineCount);
}
+
+
+ //[OneTimeTearDown]
+ //public void Cleanup()
+ //{
+ // // Remove TMP Essential Resources if they were imported in the project as a result of running tests.
+ // if (TMPro_EventManager.temporaryResourcesImported == true)
+ // {
+ // string testResourceFolderPath = Path.GetFullPath("Assets/TextMesh Pro");
+
+ // if (Directory.Exists(testResourceFolderPath))
+ // {
+ // Directory.Delete(testResourceFolderPath);
+ // File.Delete(Path.GetFullPath("Assets/TextMesh Pro.meta"));
+ // }
+
+ // TMPro_EventManager.temporaryResourcesImported = false;
+ // }
+ //}
+
}
}
diff --git a/Tests/Runtime/com.unity.textmeshpro.RuntimeTests.asmdef b/Tests/Runtime/Unity.TextMeshPro.Tests.asmdef
similarity index 62%
rename from Tests/Runtime/com.unity.textmeshpro.RuntimeTests.asmdef
rename to Tests/Runtime/Unity.TextMeshPro.Tests.asmdef
index 285e09a..9fef4d6 100644
--- a/Tests/Runtime/com.unity.textmeshpro.RuntimeTests.asmdef
+++ b/Tests/Runtime/Unity.TextMeshPro.Tests.asmdef
@@ -1,7 +1,7 @@
{
- "name": "com.unity.textmeshpro.RuntimeTests",
+ "name": "Unity.TextMeshPro.Tests",
"references": [
- "com.unity.textmeshpro.Runtime"
+ "Unity.TextMeshPro"
],
"optionalUnityReferences": [
"TestAssemblies"
diff --git a/Tests/Runtime/com.unity.textmeshpro.RuntimeTests.asmdef.meta b/Tests/Runtime/Unity.TextMeshPro.Tests.asmdef.meta
similarity index 100%
rename from Tests/Runtime/com.unity.textmeshpro.RuntimeTests.asmdef.meta
rename to Tests/Runtime/Unity.TextMeshPro.Tests.asmdef.meta
diff --git a/package.json b/package.json
index ce50f0a..19b21d7 100644
--- a/package.json
+++ b/package.json
@@ -1,7 +1,8 @@
{
"name": "com.unity.textmeshpro",
- "version": "1.2.0",
- "unity": "2018.2",
+ "displayName": "TextMesh Pro",
+ "version": "1.2.1",
+ "unity": "2018.1",
"description": "TextMesh Pro is the ultimate text solution for Unity. It's the perfect replacement for Unity's UI Text and the legacy Text Mesh.\n\nPowerful and easy to use, TextMesh Pro uses Advanced Text Rendering techniques along with a set of custom shaders; delivering substantial visual quality improvements while giving users incredible flexibility when it comes to text styling and texturing.\n\nTextMesh Pro provides Improved Control over text formatting and layout with features like character, word, line and paragraph spacing, kerning, justified text, Links, over 30 Rich Text Tags available, support for Multi Font & Sprites, Custom Styles and more.\n\nGreat performance. Since the geometry created by TextMesh Pro uses two triangles per character just like Unity's text components, this improved visual quality and flexibility comes at no additional performance cost.",
"keywords": [ "TextMeshPro", "TextMesh Pro", "Text", "SDF" ],
"category": "Text Rendering",
diff --git a/Scripts/Runtime/com.unity.textmeshpro.Runtime.asmdef.meta b/Scripts/Runtime/Unity.TextMeshPro.asmdef.meta
similarity index 100%
rename from Scripts/Runtime/com.unity.textmeshpro.Runtime.asmdef.meta
rename to Scripts/Runtime/Unity.TextMeshPro.asmdef.meta
diff --git a/Tests/Editor/TMP_EditorTests.cs b/Tests/Editor/TMP_EditorTests.cs
index e89418f..bf3d58e 100644
--- a/Tests/Editor/TMP_EditorTests.cs
+++ b/Tests/Editor/TMP_EditorTests.cs
@@ -6,7 +6,6 @@
using System.Collections;
-
namespace TMPro
{
[Category("Text Parsing & Layout")]
@@ -61,6 +60,14 @@ public class TMP_EditorTests
[OneTimeSetUp]
public void Setup()
{
+ if (Directory.Exists(Path.GetFullPath("Assets/TextMesh Pro")) == false)
+ {
+ Debug.Log("Skipping over Editor tests as TMP Essential Resources are missing from the current test project.");
+ Assert.Ignore();
+
+ return;
+ }
+
GameObject textObject = new GameObject("Text Object");
m_TextComponent = textObject.AddComponent();
@@ -184,10 +191,14 @@ public void TextParsing_TextInfoTest_RichText(int sourceTextIndex, int character
//[OneTimeTearDown]
//public void Cleanup()
//{
// // Remove TMP Essential Resources which were imported in the project.
// if (Directory.Exists(Path.GetFullPath("Assets/TextMesh Pro")))
// {
- // AssetDatabase.DeleteAsset("Assets/TextMesh Pro");
+ // if (Directory.Exists(Path.GetFullPath("Assets/TextMesh Pro")))
+ // {
+ // AssetDatabase.DeleteAsset("Assets/TextMesh Pro");
+ // TMPro_EventManager.temporaryResourcesImported = false;
+ // }
// }
//}
@@ -184,10 +191,14 @@ public void TextParsing_TextInfoTest_RichText(int sourceTextIndex, int character
//public void Cleanup()
//{
- // // Remove TMP Essential Resources which were imported in the project.
- // if (Directory.Exists(Path.GetFullPath("Assets/TextMesh Pro")))
+ // // Remove TMP Essential Resources if they were imported in the project as a result of running tests.
+ // if (TMPro_EventManager.temporaryResourcesImported == true)
// {